@@ -10,7 +10,7 @@ from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_true_y, get_visual_info_regressor
 from Accuinsight.modeler.core.sklearnModelType import REGRESSION, CLASSIFICATION
 from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_PARAMS, SELECTED_METRICS, VALUE_ERROR, \
-    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL
+    LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, USER_ID
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, \
     set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
@@ -30,10 +30,13 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(Common):
     def __init__(self):
-        global feature_name, alarm, alarm_api, message_param
+        global feature_name, alarm, alarm_api, message_param, user_id
         super().__init__()
 
         feature_name = None
+        user_id = None
+        message_param = ''
+
         alarm = self.workspace_alarm
         alarm_api = self.workspace_alarm_api
 
@@ -69,7 +72,15 @@ class accuinsight(Common):
 
     def unset_message(self):
         global message_param
-        message_param = None
+        message_param = ''
+
+    def set_user_id(self, uid):
+        global user_id
+        user_id = uid
+
+    def unset_user_id(self):
+        global user_id
+        user_id = None
 
     class add_experiment(object):
         def __init__(self, model_name, *args, model_monitor=False):
@@ -173,6 +184,9 @@ class accuinsight(Common):
             self.summary_info[LOGGING_RUN_ID] = func.get_run_id()
             self.summary_info[FITTED_MODEL] = self.fitted_model
 
+            if user_id is not None:
+                self.summary_info[USER_ID] = user_id
+
             set_prefix_path(self.dict_path[LcConst.RUN_PREFIX_PATH])
             set_run_name(self.fitted_model, self.summary_info[LOGGING_RUN_ID])
 
