@@ -43,6 +43,7 @@ class accuinsight(Common):
         thresholds = self.thresholds
         alarm = self.workspace_alarm
         alarm_api = self.workspace_alarm_api
+        user_id = self.user_id
 
         if best_weights:
             best_weights_on = True
@@ -120,6 +121,9 @@ class accuinsight(Common):
                 self.model_summary['run_id'] = func.get_run_id()
                 self.model_summary['model_type'] = get.model_type(self.model)
 
+                if user_id is not None:
+                    self.model_summary['user_id'] = user_id
+
                 if hasattr(self.model.loss, 'get_config'):
                     self.model_summary['loss_function'] = self.model.loss.get_config()['name']
                 else:
@@ -212,29 +216,13 @@ class accuinsight(Common):
                 if self.verbose > 0:
                     print('Using epoch %05d with %s: %0.5f' % (self.best_epochs, self.monitor, self.best))
                 self.model.set_weights(self.best_weights)  # set best model's weights
-
-#                self.model_summary = OrderedDict()
-#                self.model_summary['data_version'] = endpoint
-#                self.model_summary['model_description'] = description
-#                self.model_summary['logging_time'] = get_time.logging_time()
-#                self.model_summary['run_id'] = self.run_id
-#                self.model_summary['model_type'] = self.model_type
-#
-#                if hasattr(self.model.loss, 'get_config'):
-#                    self.model_summary['loss_function'] = self.model.loss.get_config()['name']
-#                else:
-#                    self.model_summary['loss_function'] = self.model.loss
-#
-#                self.model_summary['optimizer_info'] = {type(self.model.optimizer).__name__: self.model.optimizer.get_config()}
                 
                 end = get_time.now()
                 self.model_summary['time_delta'] = str(end - start)
                 self.model_summary['selected_metrics'] = {self.monitor: self.best}
             
                 # path for model_info.json
-                self.path_for_setting_model_json = self.dict_path['model_json']
-                set_model_json_path(self.path_for_setting_model_json)
-            
+                set_model_json_path(self.dict_path['model_json'])
                 model_json_full_path = self.dict_path['model_json_full']
             
                 with open(model_json_full_path, 'w', encoding='utf-8') as save_file:
