@@ -44,6 +44,7 @@ class accuinsight(Common):
         thresholds = self.thresholds
         alarm = self.workspace_alarm
         alarm_api = self.workspace_alarm_api
+        user_id = self.user_id
     
         if best_weights:
             best_weights_on = True
@@ -117,6 +118,9 @@ class accuinsight(Common):
                 self.model_summary['run_id'] = func.get_run_id()
                 self.model_summary['model_type'] = get.model_type(self.model)
 
+                if user_id is not None:
+                    self.model_summary['user_id'] = user_id
+
                 if hasattr(self.model.loss, 'get_config'):
                     self.model_summary['loss_function'] = self.model.loss.get_config()['name']
                 else:
