@@ -1,3 +1,4 @@
+import os
 import argparse
 import subprocess
 from Accuinsight.modeler.clients.modeler_api import WorkspaceRestApi
@@ -25,29 +26,28 @@ class WorkspaceRun:
         parser = argparse.ArgumentParser()
         parser.add_argument('--workspaceRunId', default=None)
         parser.add_argument('--codePath', default=None)
-        parser.add_argument('--stopFlag', default=False)
-        parser.add_argument('--stopTimeout', default=600)
         parser.add_argument('--argument', default='')
 
         args, unknown = parser.parse_known_args()
         args_dict = vars(args)
 
         if not args_dict['argument'] == '':
-            self.custom_args = args_dict['argument']\
-                .replace('[[:space:]]', " ").replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')
+            self.custom_args = ' ' + args_dict['argument']\
+                .replace('[[:space:]]', ' ').replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')
 
         self.code_path = args_dict['codePath']
         self.workspace_run_log.workspace_run_id = args_dict['workspaceRunId']
-        self.workspace_run_log.stop_flag = args_dict['stopFlag']
-        self.workspace_run_log.stop_timeout = args_dict['stopTimeout']
 
         if not self.code_path:
             raise Exception("codePath cannot be none")
 
+        new_env = os.environ.copy()
+        new_env['PATH'] = '/opt/conda/bin:' + new_env['PATH']
+
         try:
-            subprocess.run("python3 -u %s %s > /tmp/output_%s.log 2>&1" %
+            subprocess.run("/opt/conda/bin/python -u '%s'%s > /tmp/output_%s.log 2>&1" %
                            (self.code_path, self.custom_args, self.workspace_run_log.workspace_run_id),
-                           shell=True, encoding='UTF-8').check_returncode()
+                           shell=True, encoding='UTF-8', env=new_env).check_returncode()
             self.workspace_run_log.is_success = True
         except subprocess.CalledProcessError:
             self.workspace_run_log.is_success = False
