@@ -1,3 +1,5 @@
+import json
+
 from Accuinsight.modeler.entities import Run
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcCreateRun, LifecycleService, LcGitInfo, LcPyDepen
 from Accuinsight.modeler.store.tracking.lc_abstract_store import AbstractStore as LcAbstractStore
@@ -7,7 +9,7 @@ from Accuinsight.modeler.utils.os_getenv import get_os_env
 from Accuinsight.modeler.core.Run.ParseRun import BaseParser
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run, dict_to_list
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_OBJ_NAME, SOURCE_FILE_GIT_META, PYTHON_DEPENDENCY, \
-    SOURCE_FILE_GIT_REPO, SOURCE_FILE_GIT_COMMIT_ID
+    SOURCE_FILE_GIT_REPO, SOURCE_FILE_GIT_COMMIT_ID, RUN_MODEL_JSON_PATH
 from Accuinsight.modeler.entities.lc_run_info import LcRunInfo as EntityRunInfo
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.entities.lc_artifact import LcArtifact as EntityArtifact
@@ -90,10 +92,18 @@ class RestStore(LcAbstractStore):
         project_id = str(env_value[LcConst.ENV_PROJECT_ID])
         workspace_id = str(env_value[LcConst.ENV_WORKSPACE_ID])
         experiment_id = str(env_value[LcConst.ENV_EXPERIMENT_ID])
-        userId = str(env_value[LcConst.ENV_USER_SSO_ID])
+        user_id = str(env_value[LcConst.ENV_USER_SSO_ID])  # owner id
         language_id = str(env_value[LcConst.ENV_LANGUAGE_ID])
 
-        run_proto = _set_run_info(current_run_meta, userId).to_proto()
+        with open(current_run_meta['result_path'][RUN_MODEL_JSON_PATH]) as run_json_file:
+            json_data = json.load(run_json_file)
+
+            try:
+                user_id = json_data['user_id']
+            except KeyError:
+                pass
+
+        run_proto = _set_run_info(current_run_meta, user_id).to_proto()
 
         git_meta = {'filename': '', 'repo': '', 'commit': ''}
         git_meta_data = LcGitInfo(
@@ -135,7 +145,7 @@ class RestStore(LcAbstractStore):
                 project_id=project_id,
                 workspace_id=workspace_id,
                 experiment_id=experiment_id,
-                userId=userId,
+                userId=user_id,
                 language_id=language_id,
                 #path=git_meta['filename'], # TODO brian_todo set model file path
                 #name='dummy.py', # TODO brian_todo set model file name
